<?php
namespace Teknisa\CRM\Controller;

use Teknisa\CRM\Controller\TeknisaCrud;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Request\Row;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\Remote\FileUploader\Server;


class crm20000CasoAnexosController extends TeknisaCrud
{
    protected $dataSourceName = 'crm_anexocontato';
    
    protected $zhFileUploader;
    protected $newCode;
    protected $anexosCasoService;
    
    public function __construct($crudService, $parameterBag, Server $zhFileUploader, $newCode, $anexosCasoService) {
        
		$this->zhFileUploader       = $zhFileUploader;
		$this->newCode              = $newCode; 
		$this->anexosCasoService    = $anexosCasoService;

    	parent::__construct($crudService, $parameterBag);
	}
    
    public function save(Request $request, Response $response) {
        
        $rows = $request->getDataSet()->getRows();
        $index = 0;
        foreach ($rows as &$row) {
            $row["DSCAMINHO"] = $row["DSCAMINHO"][$index++]["path"];
            $row["NRANEXOCONTATO"] = $this->newCode->getCodeByTableName("CRM_ANEXOCONTATO", $row["NRORG"]);
        }
        
        try{
            $hasAnnex = $this->anexosCasoService->callForCheckIfHasAnnex($rows[0]);
            
            parent::save($request, $response);
            
            if(!$hasAnnex){
                $this->anexosCasoService->callForUpdateIdAnnex($rows[0], "S");
            }
        }
        catch(\Exception $e){
            throw $e;
        }
    }
    
    public function delete(Request $request, Response $response){
        
        $row = $request->getRow();
        
        $this->zhFileUploader->deleteFile($row["DSCAMINHO"]);
        
        try{
            parent::delete($request, $response);
            
            $hasAnnex = $this->anexosCasoService->callForCheckIfHasAnnex($row);
            
            if(!$hasAnnex){
                $this->anexosCasoService->callForUpdateIdAnnex($row, "N");
            }
        }
        catch(\Exception $e){
            throw $e;
        }
        
    }
    
    public function deleteFilesByOriginNumber(Row $row){
        
        $row = $row->getRow();
        
        $fileUrls = self::getFilesUrlByOriginNumber($row);
        
        if($fileUrls){
            
            foreach ($fileUrls as $url) {
                
                $this->zhFileUploader->deleteFile($url["DSCAMINHO"]); 
                
            }
            
        }
        
        $this->anexosCasoService->callForDeleteFilesByOriginNumber($row);
        
    }
    
    public function getFilesUrlByOriginNumber($row){
        
        $fileUrls = $this->anexosCasoService->callForGetFilesUrlByOriginNumber($row);
        
        return $fileUrls;
    }
    
}
?>